@@ -1,14 +1,12 @@
 #!/usr/bin/python
 
-"""
-This module is callable via the command line
-but importing it does nothing.
-"""
-
+import sys, getopt
 
 def main():
     print('Welcome to Python Phast Web Services')
 
+def method2():
+    print('This is method 2')
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
